{
  pkgs,
  osConfig,
  ...
}: {
  imports = [
    ./shell/helix
    ./shell/zellij
    ./shell/zsh.nix
    ./shell/starship.nix
    ./shell/eza.nix
    ./shell/hyfetch.nix
  ];
  home = {
    username = "lillian";
    homeDirectory = "/home/lillian";
    file."id_ed25519.pub" = {
      source = ../hosts/${osConfig.networking.hostName}/id_ed25519.pub;
      target = ".ssh/id_ed25519.pub";
      force = true;
    };
  };

  catppuccin = {
    enable = true;
    flavor = "macchiato";
    foot.enable = false;
    helix.enable = false;
    yazi.enable = false;
  };

  home.packages = with pkgs; [
    # System tools:
    vscode-langservers-extracted
    sops
    zsh
    bat
    btop
    broot
    lazygit
    navi
    nil
  ];
  programs = {
    navi.enable = true;
    yazi = {
      enable = true;
      package = pkgs.yazi.override {
        _7zz = pkgs._7zz.override {useUasm = true;};
      };
    };
  };
  stylix.enable = true;
  # stylix = {
  #   enable = true;
  #   autoEnable = true;
  #   base16Scheme = {
  #     scheme = "Catppuccin Macchiato";
  #     author = "https://github.com/catppuccin/catppuccin";
  #     base00 = "24273a";
  #     base01 = "1e2030";
  #     base02 = "363a4f";
  #     base03 = "494d64";
  #     base04 = "5b6078";
  #     base05 = "cad3f5";
  #     base06 = "f4dbd6";
  #     base07 = "b7bdf8";
  #     base08 = "ed8796";
  #     base09 = "f5a97f";
  #     base0A = "eed49f";
  #     base0B = "a6da95";
  #     base0C = "8bd5ca";
  #     base0D = "8aadf4";
  #     base0E = "c6a0f6";
  #     base0F = "f0c6c6";
  #   };
  #   image = ./background.jpg;
  #   cursor.package = pkgs.catppuccin-cursors;
  #   cursor.name = "macchiatoMauve";
  # };
}
